Method: RubyToAnsiC#process_cvar

Defined in:
lib/ruby_to_ansi_c.rb

#process_cvar(exp) ⇒ Object

Constants, must be defined in the global env.

TODO: This will cause a lot of errors with the built in classes until we add them to the bootstrap phase. HACK: what is going on here??? We have NO tests for this node



330
331
332
333
334
# File 'lib/ruby_to_ansi_c.rb', line 330

def process_cvar(exp)
  # TODO: we should treat these as globals and have them in the top scope
  name = exp.shift
  return name.to_s
end