Method: RubyToAnsiC#prototypes
- Defined in:
- lib/ruby_to_ansi_c.rb
#prototypes ⇒ Object (readonly)
Provides access to the method signature prototypes that are needed at the top of the C file.
76 77 78 |
# File 'lib/ruby_to_ansi_c.rb', line 76 def prototypes @prototypes end |